==> gbsite-1.0.0.tar.gz: gbsite/templates/gborg/gborg_homepage.php <==
<table cellspacing="2" cellpadding="2" border="0" width="100%">
<tr>
<td valign="top" width="60%">
	<table cellspacing="0" cellpadding="2" border="0" width="100%">
	<tr>
	<td><font face="<?= $font_1 ?>" size="2">
	<p><b>Welcome to GreatBridge.org!</b></p>
	<p>This website is the beginning of what we hope will be a substantial contribution to the open source community by Great Bridge LLC, the company providing open source solutions based on the PostgreSQL database.</p>
	<p>GreatBridge.org provides project hosting, development tools, and lots of other great stuff for the open source projects that GreatBridge.org supports. We want to take the administrative headaches out of open source projects, and let hackers concentrate on hacking.</p>
	<? if(empty($member_id)) {
	     if(empty($site_member)) { ?>
        <p>We do ask that you <a href="/member/memjoin.php">sign up</a> to be a member of GreatBridge.org - it's free, and only takes a few minutes.</p>
          <? } else { ?>
	<p>Welcome back, <?= $site_member ?>.  Please <a href="/member/memlogin.php">log in</a>.</p>
	  <? } ?>
	<? } ?>
	</font>
	</td>
	</tr>
	<!-- spacer -->
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr bgcolor="<?= $color_5 ?>">
	<td><font face="<?= $font_1 ?>" size="2" color="<?= $color_2 ?>"><b>Latest News</b></font></td>
	</tr>
<? while(list(,$projnews) = @each($news_list)) { ?>
	<tr>
	<td><font face="<?= $font_1 ?>" size="2">
	<font color="<?= $color_6 ?>"><b><?= $projnews["headline"] ?></b></font>
	<br>
	<b>posted by:</b> <a href="/member/memprofile.php?<?= $projnews["member_id"] ?>"><?= $projnews["member_name"] ?></a> on <?= $projnews["submit_date"] ?>
	<br><br>
	<?= substr($projnews["body"],0,150) ?><? if (strlen($projnews["body"]) > 150){ ?>...<? } ?> 
	<br>	
	<? if (strlen($projnews["body"]) > 150)
		echo "<a href=/project/" . $projnews["project_name"] . "/news/newsfull.php?news_id=" . $projnews["news_id"] . ">click here for the full story.</a><br>";
	?>
	<br>
	</font>
	</td>
	</tr>
	<tr>
	<td bgcolor="<?= $color_7 ?>"><center><img src="<?= $image_path ?>/shim.gif" width="1" height="2"></center></td>
	</tr>
<? } # end the news_list loop ?>
	</table>
</td>
<td valign="top" width="40%" bgcolor="<?= $color_4 ?>">
	<table cellspacing="0" cellpadding="1" border="0" width="100%" bgcolor="<?= $color_2 ?>">
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Browse Projects</b></font></td>
	</tr>
	<tr>
	<td>
	<!-- loop through categories -->
	<? function traverse_cats($t_nav_tree, $indent_code,$max_depth = -1, $depth = 0) {
        global $image_path;
        global $font_1;
        if(is_array($t_nav_tree)) {
            $depth++;
            if($max_depth != -1 && $depth > $max_depth) return;
				    $entries = 0;
            $child_indent = ($indent_code!=""?"<img src=\"$image_path/browse_spacer_sub.gif\" width=\"16\" height=\"10\">":"<img src=\"$image_path/browse_spacer.gif\" width=\"19\" height=\"10\">");
                        while((list(,$branch) = @each($t_nav_tree)) && (($entries++ < 3) || ($depth == 1))) {
			?>
	<?= $indent_code . $child_indent ?><font face=<?= $font_1 ?> size="2"><a href="/browse.php?<?= $branch["cat_id"] ?>"><?= $branch["cat_name"] ?></a></font>
	<br>
			<?
			traverse_cats($branch["children"], "<img src=\"/images/gborg/shim.gif\" width=\"10\" height=\"1\">" . $indent_code,$max_depth,$depth);
            }
        }
    }
	traverse_cats($cat_list, "");
	?>
	</td>
	</tr>
	<!-- spacer -->
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>All Projects</b></font></td>
	</tr>
	<?
		while(list(,$value) = @each($proj_list)) {
		echo "
			<tr bgcolor=" . $color_7 . ">
			<td><font face=" . $font_1 . " size=2><a href=/project/" . $value["project_name"] . "/projdisplay.php><b>" . $value["project_name"] . "</b></a>&nbsp;" . $proj_status . "</font></td>
			</tr>
			<tr>
			<td>&nbsp;&nbsp;<font face=" . $font_1 . " size=2>" . $value["project_title"] . "</font></td>
			</tr>
			";
		}
	?>
	</table>
</td>
</tr>
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/gborg/gborg_homepage.php <==
<table cellspacing="2" cellpadding="2" border="0" width="100%">
<tr>
<td valign="top" width="60%">
	<table cellspacing="0" cellpadding="2" border="0" width="100%">
	<tr>
	<td><font face="<?= $font_1 ?>" size="2">
	<p><b>Welcome to GreatBridge.org!</b></p>
	<p>This website is the beginning of what we hope will be a substantial contribution to the open source community by Great Bridge LLC, the company providing open source solutions based on the PostgreSQL database.</p>
	<p>GreatBridge.org provides project hosting, development tools, and lots of other great stuff for the open source projects that GreatBridge.org supports. We want to take the administrative headaches out of open source projects, and let hackers concentrate on hacking.</p>
	<? if(empty($member_id)) {
	     if(empty($site_member)) { ?>
        <p>We do ask that you <a href="/member/memjoin.php">sign up</a> to be a member of GreatBridge.org - it's free, and only takes a few minutes.</p>
          <? } else { ?>
	<p>Welcome back, <?= $site_member ?>.  Please <a href="/member/memlogin.php">log in</a>.</p>
	  <? } ?>
	<? } ?>
	</font>
	</td>
	</tr>
	<!-- spacer -->
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr bgcolor="<?= $color_5 ?>">
	<td><font face="<?= $font_1 ?>" size="2" color="<?= $color_2 ?>"><b>Latest News</b></font></td>
	</tr>
<? $proj_news_count = 0;
   while((list(,$projnews) = @each($news_list)) && $proj_news_count++ < 5) { ?>
	<tr>
	<td><font face="<?= $font_1 ?>" size="2">
	<font color="<?= $color_6 ?>"><b><?= $projnews["headline"] ?></b></font>
	<br>
	<b>posted by:</b> <a href="/member/memprofile.php?<?= $projnews["member_id"] ?>"><?= $projnews["member_name"] ?></a> on <?= $projnews["submit_date"] ?>
	<br><br>
	<?= substr($projnews["body"],0,150) ?><? if (strlen($projnews["body"]) > 150){ ?>...<? } ?> 
	<br>	
	<? if (strlen($projnews["body"]) > 150)
		echo "<a href=/project/" . $projnews["project_name"] . "/news/newsfull.php?news_id=" . $projnews["news_id"] . ">click here for the full story.</a><br>";
	?>
	<br>
	</font>
	</td>
	</tr>
	<tr>
	<td bgcolor="<?= $color_7 ?>"><center><img src="<?= $image_path ?>/shim.gif" width="1" height="2"></center></td>
	</tr>
<? } # end the news_list loop ?>
	</table>
</td>
<td valign="top" width="40%" bgcolor="<?= $color_4 ?>">
	<table cellspacing="0" cellpadding="1" border="0" width="100%" bgcolor="<?= $color_2 ?>">
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>Browse Projects</b></font></td>
	</tr>
	<tr>
	<td>
	<!-- loop through categories -->
	<? function traverse_cats($t_nav_tree, $indent_code,$max_depth = -1, $depth = 0) {
        global $image_path;
        global $font_1;
        if(is_array($t_nav_tree)) {
            $depth++;
            if($max_depth != -1 && $depth > $max_depth) return;
				    $entries = 0;
            $child_indent = ($indent_code!=""?
                                 "<img src=\"$image_path/browse_spacer_sub.gif\" width=\"16\" height=\"10\">":
                                 "<img src=\"$image_path/browse_spacer.gif\" width=\"19\" height=\"10\">");
                        while((list(,$branch) = @each($t_nav_tree)) && ((($entries++ < $max_depth) || ($depth == 1)) || $max_depth == -1)) {
                            $count = getProjectCountInCategory($branch["cat_id"],true);
                            if($count > 0) {
			?>
	<?= $indent_code . $child_indent ?><font face=<?= $font_1 ?> size="2"><a href="/browse.php?<?= $branch["cat_id"] ?>"><?= $branch["cat_name"] ?></a> (<?= $count ?>)</font>
	<br>
			<?
			        traverse_cats($branch["children"], "<img src=\"/images/gborg/shim.gif\" width=\"10\" height=\"1\">" . $indent_code,$max_depth,$depth);
                            }
            }
        }
    }
	traverse_cats($cat_list, "");
	?>
	</td>
	</tr>
	<!-- spacer -->
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr bgcolor="<?= $color_4 ?>">
	<td><font face="<?= $font_1 ?>" size="2"><b>All Projects</b></font></td>
	</tr>
	<?
		while(list(,$value) = @each($proj_list)) {
		echo "
			<tr bgcolor=" . $color_7 . ">
			<td><font face=" . $font_1 . " size=2><a href=/project/" . $value["project_name"] . "/projdisplay.php><b>" . $value["project_name"] . "</b></a>&nbsp;" . $proj_status . "</font></td>
			</tr>
			<tr>
			<td>&nbsp;&nbsp;<font face=" . $font_1 . " size=2>" . $value["project_title"] . "</font></td>
			</tr>
			";
		}
	?>
	</table>
</td>
</tr>
</table>
